@@ -325,6 +325,12 @@ class Miner(object):
                     if name not in checkpoint["statable"]:
                         continue
                     statable.load_state_dict(checkpoint["statable"][name])
+
+            # load plugin states
+            for plugin in self.plugins:
+                key = f"__plugin.{plugin.__class__.__name__}__"
+                plugin.load_state_dict(checkpoint.get(key, {}))
+
             msg = "checkpoint loaded"
             self.notify(msg, "success")
         self.model = self.parallel_model(self.model)
@@ -443,6 +449,7 @@ class Miner(object):
             if total_train_loss < self.lowest_train_loss:
                 self.lowest_train_loss = total_train_loss
 
+            should_persist_best = False
             if total_val_loss < self.lowest_val_loss:
                 message = (
                     "current val loss {} is lower than lowest {}, "
@@ -451,11 +458,14 @@ class Miner(object):
                     )
                 )
                 self.notify(message, "success")
-
                 self.lowest_val_loss = total_val_loss
+                should_persist_best = True
+
+            self.call_hook_func("before_persist_checkpoint")
+
+            if should_persist_best:
                 self.persist("best")
             self.persist("latest")
-
             if not self.current_epoch % self.persist_stride:
                 self.persist("epoch_{}".format(self.current_epoch))
 
@@ -576,6 +586,10 @@ class Miner(object):
         for statable_name, statable in self.statable.items():
             state["statable"][statable_name] = statable.state_dict()
 
+        for plugin in self.plugins:
+            key = f"__plugin.{plugin.__class__.__name__}__"
+            state[key] = plugin.state_dict()
+
         if self.amp and self.amp_scaler:
             state["scaler"] = self.scaler.state_dict()
 
